@@ -9,14 +9,107 @@ from queue import Empty as SyncQueueEmpty
 from queue import Full as SyncQueueFull
 from typing import Any, Callable, Deque, Generic, List, Optional, Set, TypeVar
 
-__version__ = "0.6.2"
-__all__ = ("Queue", "PriorityQueue", "LifoQueue")
+from typing_extensions import Protocol
+
+__version__ = "0.7.0"
+__all__ = (
+    "Queue",
+    "PriorityQueue",
+    "LifoQueue",
+    "SyncQueue",
+    "AsyncQueue",
+    "BaseQueue",
+)
 
 
 T = TypeVar("T")
 OptFloat = Optional[float]
 
 
+class BaseQueue(Protocol[T]):
+    @property
+    def maxsize(self) -> int:
+        ...
+
+    @property
+    def closed(self) -> bool:
+        ...
+
+    def task_done(self) -> None:
+        ...
+
+    def qsize(self) -> int:
+        ...
+
+    @property
+    def unfinished_tasks(self) -> int:
+        ...
+
+    def empty(self) -> bool:
+        ...
+
+    def full(self) -> bool:
+        ...
+
+    def put_nowait(self, item: T) -> None:
+        ...
+
+    def get_nowait(self) -> T:
+        ...
+
+
+class SyncQueue(BaseQueue[T], Protocol[T]):
+    @property
+    def maxsize(self) -> int:
+        ...
+
+    @property
+    def closed(self) -> bool:
+        ...
+
+    def task_done(self) -> None:
+        ...
+
+    def qsize(self) -> int:
+        ...
+
+    @property
+    def unfinished_tasks(self) -> int:
+        ...
+
+    def empty(self) -> bool:
+        ...
+
+    def full(self) -> bool:
+        ...
+
+    def put_nowait(self, item: T) -> None:
+        ...
+
+    def get_nowait(self) -> T:
+        ...
+
+    def put(self, item: T, block: bool = True, timeout: OptFloat = None) -> None:
+        ...
+
+    def get(self, block: bool = True, timeout: OptFloat = None) -> T:
+        ...
+
+    def join(self) -> None:
+        ...
+
+
+class AsyncQueue(BaseQueue[T], Protocol[T]):
+    async def put(self, item: T) -> None:
+        ...
+
+    async def get(self) -> T:
+        ...
+
+    async def join(self) -> None:
+        ...
+
+
 current_loop = getattr(asyncio, "get_running_loop", None)
 if current_loop is None:
     current_loop = asyncio.get_event_loop
@@ -39,7 +132,7 @@ class Queue(Generic[T]):
         self._async_mutex = asyncio.Lock()
         if sys.version_info[:3] == (3, 10, 0):
             # Workaround for Python 3.10 bug, see #358:
-            getattr(self._async_mutex, '_get_loop', lambda: None)()
+            getattr(self._async_mutex, "_get_loop", lambda: None)()
         self._async_not_empty = asyncio.Condition(self._async_mutex)
         self._async_not_full = asyncio.Condition(self._async_mutex)
         self._finished = asyncio.Event()
@@ -181,7 +274,7 @@ class Queue(Generic[T]):
             raise RuntimeError("Operation on the closed queue is forbidden")
 
 
-class _SyncQueueProxy(Generic[T]):
+class _SyncQueueProxy(SyncQueue[T]):
     """Create a queue object with a given maximum size.
 
     If maxsize is <= 0, the queue size is infinite.
@@ -354,7 +447,7 @@ class _SyncQueueProxy(Generic[T]):
         return self.get(block=False)
 
 
-class _AsyncQueueProxy(Generic[T]):
+class _AsyncQueueProxy(AsyncQueue[T]):
     """Create a queue object with a given maximum size.
 
     If maxsize is <= 0, the queue size is infinite.
